]> Sergey Matveev's repositories - nnn.git/commitdiff
nnn is a file manager now
authorArun Prakash Jana <engineerarun@gmail.com>
Mon, 6 Aug 2018 23:22:39 +0000 (04:52 +0530)
committerArun Prakash Jana <engineerarun@gmail.com>
Mon, 6 Aug 2018 23:22:39 +0000 (04:52 +0530)
README.md
nnn.1
nnn.c
packagecore.yaml

index 42f9769e49a38c9590663240e95ab47c40f1b24c..8f12df33a462e3cb346f7872c5cc772bdddabba9 100644 (file)
--- a/README.md
+++ b/README.md
@@ -21,7 +21,7 @@ Noice is Not Noice, a noicer fork...
 
 <p align="center"><i>nnn in action! (click to play video)</i></a></p>
 
-`nnn` is probably the [fastest and most resource-sensitive](#performance) (with all its capabilities) file browser you have ever used. It's extremely flexible too - integrates with your DE and favourite GUI utilities, works with the desktop opener, supports bookmarks, has smart navigation shortcuts, [navigate-as-you-type](#navigate-as-you-type-mode) mode, disk usage analyzer mode, comprehensive file details and much more. `nnn` was initially forked from [noice](http://git.2f30.org/noice/) but is significantly [different](https://github.com/jarun/nnn/wiki/nnn-vs.-noice) today.
+`nnn` is probably the [fastest and most resource-sensitive](#performance) (with all its capabilities) file manager you have ever used. It's extremely flexible too - integrates with your DE and favourite GUI utilities, works with the desktop opener, supports bookmarks, has smart navigation shortcuts, [navigate-as-you-type](#navigate-as-you-type-mode) mode, disk usage analyzer mode, comprehensive file details and much more. `nnn` was initially forked from [noice](http://git.2f30.org/noice/) but is significantly [different](https://github.com/jarun/nnn/wiki/nnn-vs.-noice) today.
 
 If you want to edit a file in vi with some soothing music in the background while referring to a spec in your GUI PDF viewer, `nnn` got it! [Quickstart](#quickstart) and see how `nnn` simplifies those long desktop sessions...
 
@@ -107,7 +107,7 @@ Have fun with it! Missing a feature? Want to contribute? Head to the rolling [To
   - Copy absolute file paths with/without X (*easy* shell integration)
   - Change directory at exit (*easy* shell integration)
   - Open any file in EDITOR (fallback vi) or PAGER (fallback less)
-  - Open current directory in a custom GUI file browser
+  - Open current directory in a custom GUI file manager
   - Terminal screensaver/locker (default vlock, customizable) integration
 - Unicode support
 - Highly optimized code, minimal resource usage
@@ -182,7 +182,7 @@ Search keyword and option completion scripts for Bash, Fish and Zsh can be found
 usage: nnn [-b key] [-c N] [-e] [-i] [-l]
            [-p nlay] [-S] [-v] [-h] [PATH]
 
-The missing terminal file browser for X.
+The missing terminal file manager for X.
 
 positional arguments:
   PATH   start dir [default: current dir]
diff --git a/nnn.1 b/nnn.1
index d7190c947763cae3bfca00634492d758e1e5ce6e..0c71ebd95f41eef319cbcbe21535ef17aca30f93 100644 (file)
--- a/nnn.1
+++ b/nnn.1
@@ -3,7 +3,7 @@
 .Os
 .Sh NAME
 .Nm nnn
-.Nd the missing terminal file browser for X
+.Nd the missing terminal file manager for X
 .Sh SYNOPSIS
 .Nm
 .Op Ar -b key
@@ -18,7 +18,7 @@
 .Op Ar PATH
 .Sh DESCRIPTION
 .Nm
-(Noice is Not Noice) is a performance-optimized, feature-packed fork of the noice terminal file browser with seamless desktop integration, simplified navigation, \fInavigate-as-you-type\fR mode, bookmarks, disk usage analyzer mode, comprehensive file details and much more. It remains a simple and efficient file browser that stays out of your way.
+(Noice is Not Noice) is a performance-optimized, feature-packed fork of noice (http://git.2f30.org/noice/) with seamless desktop integration, simplified navigation, \fInavigate-as-you-type\fR mode, bookmarks, disk usage analyzer mode, comprehensive file details and much more. It remains a simple and efficient file manager that stays out of your way.
 .Pp
 .Nm
 opens the current working directory by default if
diff --git a/nnn.c b/nnn.c
index 3bad05694a276b1e1f4da1597a88b26c3afee8b8..179a804ee15f148465702e66df4ce5c42e6acc5e 100644 (file)
--- a/nnn.c
+++ b/nnn.c
@@ -3319,7 +3319,7 @@ usage(void)
 {
        printf("usage: nnn [-b key] [-c N] [-e] [-i] [-l]\n"
                "           [-p nlay] [-S] [-v] [-h] [PATH]\n\n"
-               "The missing terminal file browser for X.\n\n"
+               "The missing terminal file manager for X.\n\n"
                "positional arguments:\n"
                "  PATH   start dir [default: current dir]\n\n"
                "optional arguments:\n"
@@ -3446,7 +3446,7 @@ main(int argc, char *argv[])
        if (!player)
                player = utils[NLAY];
 
/* Get the desktop file browser, if set */
        desktop_manager = getenv("NNN_DE_FILE_MANAGER");
 
        /* Get screensaver wait time, if set; copier used as tmp var */
index 1ab1535fb459a36cd826aeb2c394b05e1fb7c62b..d96429dc06a66b2f91fe04b47d8a196820cdd205 100644 (file)
@@ -1,7 +1,7 @@
 name: nnn
 maintainer: Arun Prakash Jana <engineerarun@gmail.com>
 license: BSD 2-Clause
-summary: The missing terminal file browser for X.
+summary: The missing terminal file manager for X.
 homepage: https://github.com/jarun/nnn
 commands:
   install:
@@ -3446,7 +3446,7 @@ main(int argc, char *argv[])
                player = utils[NLAY];
 
-       /* Get the desktop file browser, if set */
+       /* Get the desktop file manager, if set */
        desktop_manager = getenv("NNN_DE_FILE_MANAGER");
 